Files
project_6/cccl_upstream/cudax/examples/stf/04-fibonacci.cu
muh-bot dedf08166a [CCCL] Add missing CCCL components: c2h, nvbench_helper, cmake, cudax, AGENTS.md
Added 863 files from NVIDIA/cccl sparse checkout:
- c2h/ (27 files): Catch2 test helpers — generators, validators, runner
- nvbench_helper/ (10 files): Benchmark harness utilities
- cmake/ (29 files): CMake presets and build helpers
- cudax/ (794 files): Experimental CUDA extensions
- AGENTS.md: NVIDIA's official AI agent instructions for CCCL
- CMakePresets.json: Standardized build configurations
- cccl-version.json: Version tracking

Also added CCCL_ASSET_MAP.md mapping all 4295 CCCL files to
competition value and PRD items.

cccl_upstream now covers 100% of competition-critical assets:
- 27 tuning headers (SM80/90/100 benchmark data)
- 32 dispatch headers (algorithm implementations)
- 60 Thrust examples (correctness verification)
- 217 CUB Catch2 tests (regression matrix)
- 153 CUB benchmarks (parameter space search)
- 18 CUB examples (API verification)
- 27 test helpers + benchmark harness
- 794 cudax experimental extensions
2026-08-06 02:14:18 +00:00

76 lines
1.7 KiB
Plaintext

//===----------------------------------------------------------------------===//
//
// Part of CUDASTF in CUDA C++ Core Libraries,
// under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
//
//===----------------------------------------------------------------------===//
/**
* @file
*
* @brief An example of Fibonacci sequence illustrating how we can use
* dynamically created logical data
*/
#include <cuda/experimental/stf.cuh>
using namespace cuda::experimental::stf;
int fibo_ref(int n)
{
if (n < 2)
{
return n;
}
else
{
return fibo_ref(n - 1) + fibo_ref(n - 2);
}
}
__global__ void add(slice<int> out, const slice<const int> in1, const slice<const int> in2)
{
out(0) = in1(0) + in2(0);
}
__global__ void set(slice<int> out, int val)
{
out(0) = val;
}
logical_data<slice<int>> compute_fibo(context& ctx, int n)
{
auto out = ctx.logical_data(shape_of<slice<int>>(1));
if (n < 2)
{
ctx.task(out.write())->*[=](cudaStream_t s, auto sout) {
set<<<1, 1, 0, s>>>(sout, n);
};
}
else
{
auto fib1 = compute_fibo(ctx, n - 1);
auto fib2 = compute_fibo(ctx, n - 2);
ctx.task(fib1.read(), fib2.read(), out.write())->*[=](cudaStream_t s, auto s1, auto s2, auto sout) {
add<<<1, 1, 0, s>>>(sout, s1, s2);
};
}
return out;
}
int main(int argc, char** argv)
{
int n = (argc > 1) ? atoi(argv[1]) : 4;
context ctx; // = graph_ctx();
auto result = compute_fibo(ctx, n);
ctx.host_launch(result.read())->*[&](auto res) {
EXPECT(res(0) == fibo_ref(n));
};
ctx.finalize();
}